#ifndef _TRIAL_DIVISION_ALGORITHM
#define _TRIAL_DIVISION_ALGORITHM
// https://en.wikipedia.org/wiki/Trial_division

#include <vector>
#include <stdio.h>
#include "../bigint/bigint.cpp"

std::vector<bigint> trial_division(bigint n);

#endif
